use regex::Captures;
use eyre::Result;
use super::*;
use crate::utils::constructors::episode_name;

pub struct DashInTitle {}
impl Rule for DashInTitle {
    fn check(_filename: &str, captures: &Captures) -> Option<NonCompliantReason> {
        if captures.name("titleSeparator").is_some() {
            return Some(NonCompliantReason::DashInTitle)
        }

        let title = captures.name("title").unwrap();

        if title.as_str().contains("-") {
            return Some(NonCompliantReason::DashInTitle)
        }

        return None
    }

    fn fix(_filename: &str, captures: &Captures) -> Result<FixStatus> {
        let ep_name = match captures.name("name") {
            Some(ep) => Some(ep.as_str().to_string()),
            None => None
        };

        let name = episode_name(
            captures.name("title").unwrap().as_str().to_string(),
            captures.name("season").unwrap().as_str().to_string(),
            captures.name("episode").unwrap().as_str().to_string(),
            ep_name,
            captures.name("ext").unwrap().as_str().to_string()
        );

        return Ok(FixStatus::Fixed(name))
    }
}