use std::fmt::{Display, Formatter};
use regex::Captures;
use eyre::Result;

mod has_fluff;
mod has_dash_in_title;
mod has_episode_name;
mod missing_separator;

pub use has_fluff::HasFluff;
pub use has_episode_name::HasEpisodeName;
pub use has_dash_in_title::DashInTitle;
pub use missing_separator::MissingSeparator;

pub enum NonCompliantReason {
    DashInTitle,
    MissingName,
    HasFluff,
    MissingNameSeparator
}

impl Display for NonCompliantReason {
    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
        match self {
            NonCompliantReason::DashInTitle => write!(f, "Title contains dash"),
            NonCompliantReason::MissingName => write!(f, "Missing episode name"),
            NonCompliantReason::HasFluff => write!(f, "Has fluff"),
            NonCompliantReason::MissingNameSeparator => write!(f, "Missing episode name separator"),
        }
    }
}

pub enum ComplianceStatus {
    NonCompliant(NonCompliantReason),
    NotMatched,
    Compliant,
    Ignored
}

pub enum FixStatus {
    Fixed(String),
    NotImplemented,
    NotFixable
}

pub trait Rule {
    fn check(filename: &str, captures: &Captures) -> Option<NonCompliantReason>;
    fn fix(filename: &str, captures: &Captures) -> Result<FixStatus>;
}
